Call subdissectors even if we're not building a protocol tree.
[obnox/wireshark/wip.git] / file.h
diff --git a/file.h b/file.h
index 4b65464a6257e03cd7e3c9f2ad26b97d8acf0095..ac60b0d6648c94c29bc91752ce13c5d343eaaac1 100644 (file)
--- a/file.h
+++ b/file.h
@@ -1,7 +1,7 @@
 /* file.h
  * Definitions for file structures and routines
  *
- * $Id: file.h,v 1.102 2003/08/05 00:01:27 guy Exp $
+ * $Id: file.h,v 1.108 2003/09/24 00:47:36 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
 
 #include "cfile.h"
 
-/* Return values from "read_cap_file()", "continue_tail_cap_file()",
-   and "finish_tail_cap_file()". */
+/* Return values from "cf_read()", "cf_continue_tail()", and
+   "cf_finish_tail()". */
 typedef enum {
        READ_SUCCESS,   /* read succeeded */
        READ_ERROR,     /* read got an error */
        READ_ABORTED    /* read aborted by user */
 } read_status_t;
 
-int  open_cap_file(char *, gboolean, capture_file *);
-void close_cap_file(capture_file *);
-read_status_t read_cap_file(capture_file *, int *);
-int  start_tail_cap_file(char *, gboolean, capture_file *);
-read_status_t continue_tail_cap_file(capture_file *, int, int *);
-read_status_t finish_tail_cap_file(capture_file *, int *);
+int  cf_open(char *, gboolean, capture_file *);
+void cf_close(capture_file *);
+read_status_t cf_read(capture_file *, int *);
+int  cf_start_tail(char *, gboolean, capture_file *);
+read_status_t cf_continue_tail(capture_file *, int, int *);
+read_status_t cf_finish_tail(capture_file *, int *);
 /* size_t read_frame_header(capture_file *); */
-gboolean save_cap_file(char *, capture_file *, gboolean, gboolean, guint);
+gboolean cf_save(char *, capture_file *, gboolean, gboolean, guint);
+gchar *cf_get_display_name(capture_file *);
 
 int filter_packets(capture_file *cf, gchar *dfilter);
+void reftime_packets(capture_file *);
 void colorize_packets(capture_file *);
 void redissect_packets(capture_file *cf);
 int print_packets(capture_file *cf, print_args_t *print_args);
 void change_time_formats(capture_file *);
-gboolean find_packet(capture_file *cf, dfilter_t *sfcode);
+
+gboolean find_packet_protocol_tree(capture_file *cf, const char *string);
+gboolean find_packet_summary_line(capture_file *cf, const char *string);
+gboolean find_packet_data(capture_file *cf, const guint8 *string,
+                         size_t string_size);
+gboolean find_packet_dfilter(capture_file *cf, dfilter_t *sfcode);
+
 guint8 get_int_value(char char_val);
 gboolean find_ascii(capture_file *cf, char *ascii_text, gboolean ascii_search, char *ftype, gboolean case_type);
-
+gboolean find_in_gtk_data(capture_file *cf, gpointer *data, char *ascii_text, gboolean case_type, gboolean search_type);
 gboolean goto_frame(capture_file *cf, guint fnumber);
 
 void select_packet(capture_file *, int);
 void unselect_packet(capture_file *);
 
-void unselect_field(void);
+void unselect_field(capture_file *);
 
 /*
  * Mark a particular frame in a particular capture.